==> AEMET-OpenData-0.1.2.tar.gz: AEMET-OpenData-0.1.2/aemet_opendata/const.py <==
# -*- coding: utf-8 -*-
"""AEMET OpenData Constants"""

AEMET_ATTR_DATA = "datos"
AEMET_ATTR_DATE = "fecha"
AEMET_ATTR_DAY = "dia"
AEMET_ATTR_FORECAST = "prediccion"
AEMET_ATTR_HUMIDITY = "humedadRelativa"
AEMET_ATTR_ID = "id"
AEMET_ATTR_IDEMA = "idema"
AEMET_ATTR_PERIOD = "periodo"
AEMET_ATTR_PRECIPITATION = "precipitacion"
AEMET_ATTR_PRECIPITATION_PROBABILITY = "probPrecipitacion"
AEMET_ATTR_SKY_STATE = "estadoCielo"
AEMET_ATTR_SNOW = "nieve"
AEMET_ATTR_SNOW_PROBABILITY = "probNieve"
AEMET_ATTR_STATION_ALTITUDE = "alt"
AEMET_ATTR_STATION_DATE = "fint"
AEMET_ATTR_STATION_HUMIDITY = "hr"
AEMET_ATTR_STATION_LATITUDE = "lat"
AEMET_ATTR_STATION_LOCATION = "ubi"
AEMET_ATTR_STATION_LONGITUDE = "lon"
AEMET_ATTR_STATION_PRECIPITATION = "prec"
AEMET_ATTR_STATION_PRESSURE = "pres"
AEMET_ATTR_STATION_PRESSURE_SEA = "pres_nmar"
AEMET_ATTR_STATION_TEMPERATURE = "ta"
AEMET_ATTR_STATION_TEMPERATURE_MAX = "tamax"
AEMET_ATTR_STATION_TEMPERATURE_MIN = "tamin"
AEMET_ATTR_STATION_TEMPERATURE_RELATIVE = "tpr"
AEMET_ATTR_STATION_WIND = "rviento"
AEMET_ATTR_STORM_PROBABILITY = "probTormenta"
AEMET_ATTR_TOWN_LATITUDE = "latitud"
AEMET_ATTR_TOWN_LATITUDE_DECIMAL = "latitud_dec"
AEMET_ATTR_TOWN_LONGITUDE = "latitud"
AEMET_ATTR_TOWN_LONGITUDE_DECIMAL = "latitud_dec"
AEMET_ATTR_SUN_RISE = "orto"
AEMET_ATTR_SUN_SET = "ocaso"
AEMET_ATTR_TEMPERATURE = "temperatura"
AEMET_ATTR_TEMPERATURE_FEELING = "sensTermica"
AEMET_ATTR_VALUE = "value"
AEMET_ATTR_WEATHER_STATION_LATITUDE = "latitud"
AEMET_ATTR_WEATHER_STATION_LONGITUDE = "longitud"
AEMET_ATTR_WIND = "vientoAndRachaMax"

API_ID_PFX = "id"
API_MIN_STATION_DISTANCE_KM = 40
API_MIN_TOWN_DISTANCE_KM = 40
API_PERIOD_24H = 24
API_PERIOD_SPLIT = 2
API_URL = "https://opendata.aemet.es/opendata/api"

ATTR_DATA = "data"
ATTR_RESPONSE = "response"

==> AEMET-OpenData-0.1.4.tar.gz: AEMET-OpenData-0.1.4/aemet_opendata/const.py <==
# -*- coding: utf-8 -*-
"""AEMET OpenData Constants"""

AEMET_ATTR_DATA = "datos"
AEMET_ATTR_DATE = "fecha"
AEMET_ATTR_DAY = "dia"
AEMET_ATTR_DIRECTION = "direccion"
AEMET_ATTR_FORECAST = "prediccion"
AEMET_ATTR_HUMIDITY = "humedadRelativa"
AEMET_ATTR_ID = "id"
AEMET_ATTR_IDEMA = "idema"
AEMET_ATTR_PERIOD = "periodo"
AEMET_ATTR_PRECIPITATION = "precipitacion"
AEMET_ATTR_PRECIPITATION_PROBABILITY = "probPrecipitacion"
AEMET_ATTR_SKY_STATE = "estadoCielo"
AEMET_ATTR_SNOW = "nieve"
AEMET_ATTR_SNOW_PROBABILITY = "probNieve"
AEMET_ATTR_SPEED = "velocidad"
AEMET_ATTR_STATION_ALTITUDE = "alt"
AEMET_ATTR_STATION_DATE = "fint"
AEMET_ATTR_STATION_HUMIDITY = "hr"
AEMET_ATTR_STATION_LATITUDE = "lat"
AEMET_ATTR_STATION_LOCATION = "ubi"
AEMET_ATTR_STATION_LONGITUDE = "lon"
AEMET_ATTR_STATION_PRECIPITATION = "prec"
AEMET_ATTR_STATION_PRESSURE = "pres"
AEMET_ATTR_STATION_PRESSURE_SEA = "pres_nmar"
AEMET_ATTR_STATION_TEMPERATURE = "ta"
AEMET_ATTR_STATION_TEMPERATURE_MAX = "tamax"
AEMET_ATTR_STATION_TEMPERATURE_MIN = "tamin"
AEMET_ATTR_STATION_TEMPERATURE_RELATIVE = "tpr"
AEMET_ATTR_STATION_WIND = "rviento"
AEMET_ATTR_STORM_PROBABILITY = "probTormenta"
AEMET_ATTR_SUN_RISE = "orto"
AEMET_ATTR_SUN_SET = "ocaso"
AEMET_ATTR_TEMPERATURE = "temperatura"
AEMET_ATTR_TEMPERATURE_FEELING = "sensTermica"
AEMET_ATTR_TOWN_LATITUDE = "latitud"
AEMET_ATTR_TOWN_LATITUDE_DECIMAL = "latitud_dec"
AEMET_ATTR_TOWN_LONGITUDE = "longitud"
AEMET_ATTR_TOWN_LONGITUDE_DECIMAL = "longitud_dec"
AEMET_ATTR_VALUE = "value"
AEMET_ATTR_WEATHER_STATION_LATITUDE = "latitud"
AEMET_ATTR_WEATHER_STATION_LONGITUDE = "longitud"
AEMET_ATTR_WIND = "vientoAndRachaMax"

API_ID_PFX = "id"
API_MIN_STATION_DISTANCE_KM = 40
API_MIN_TOWN_DISTANCE_KM = 40
API_PERIOD_24H = 24
API_PERIOD_SPLIT = 2
API_URL = "https://opendata.aemet.es/opendata/api"

ATTR_DATA = "data"
ATTR_RESPONSE = "response"
